#Methods

##"Coral Ponds"
The two "coral ponds" described in this study were assembled in Fall 2012 at the Univeristy of California Davis.  A pair of large (~900 liter) plastic tubs were filled to about 33 centimeters deep with "sand" (coral sand, size 0, Aquaglobe USA), and then ~375 liters of seawater from the distribution system (origin; Bodega Bay, CA) were added. At various time points the following items were added to the tanks; a protein skimmer, lighting/heating, sediment and coral from an existing aquarium, and "cured" rocks from Fiji (Fig. 1).  These rocks were kept in barrels for ~two months with occasional water changes in order to "cure" them (select for hardy organisms). Samples were taken over a 3-month period from November 30, 2012 to January 22, 2013 and the frequency of sampling was increased around most of these perturbations.  These aquariums were being assembled by university personnel in preparation for classroom use and therefore all timing was out of our control.

##Sampling
At each sampling time point, three kinds of samples and water chemistry data (see below) were collected. All samples were taken in triplicate. Sediment samples were taken by scooping surface sediment into a 1.5 mL centrifuge tube and then frozen. Wipes were taken by vertical swabbing of the tank walls from water surface to sediment, using 1/4 of a standard Kimwipe (Kimtech Science KimWipes Delicate Task Wipers, KIM34155) and then frozen. Water samples were taken from the middle of the water column with a freshly rinsed 1 L flask. Water samples were then filtered onto 0.1 um filters under vacuum, the filters were divided in half and then frozen.

##Water Chemistry
At every time point the following water chemistry measurements were taken; pH (American Marine Pinpoint pH Monitor Package), salinity (American Marine PINPOINT Salinity Monitor), temperature (Pinpoint Wireless Thermometer), hardness (Hanna Instruments HI 3817 Water Quality Test Kit), alkalinity (Hanna Instruments HI 3817 Water Quality Test Kit), chloride (Hanna Instruments HI 3817 Water Quality Test Kit), sulfide (Hanna Instruments HI 3817 Water Quality Test Kit), dissolved oxygen (Hanna Instruments HI96732 Dissolved Oxygen Portable Photometer), ammonia (Hanna Instruments HI96715 Waterproof Portable Medium Range Ammonia Photometer), nitrate (Hanna Instruments HI96786 Cal Check Nitrate Portable Photometer), nitrite (Hanna Instruments HI-764 Checker HC Handheld Colorimeter, For Nitrite), phosphorus (Hanna Instruments HI-736 Checker HC Handheld Colorimeter, For Phosphorus).

*Salinity conversion: http://www.chemiasoft.com/chemd/salinity_calculator

##DNA Extraction
DNA extractions were performed using a MoBio PowerSoil DNA Isolation Kit. Wipes were shredded using flame sterilized tweezers and flame sterilized scissors, then put into PowerSoil PowerBead tubes (pre-filled with beads and buffer). Sediment was mixed in the collection tube using a flame sterilized metal spatula, then a pea-sized scoop was transferred to the PowerBead tubes. Water filter halves were cut into small pieces using flame sterilized scissors, then put into PowerBead tubes. The standard extraction protocol was followed with the following changes. Ten minutes of vortexing was replaced with 60 seconds, max speed, on a bead beater (BioSpec Products), and the final elution was in 50 ul of solution C6 instead of 100 ul. Once extracted, we used Life Technologies Quant-iT dsDNA Assay Kit, High Sensitivity (REF Q33120) and an Invitrogen Qubit fluorometer (Catalogue no. Q32857) to quantify the DNA.

##16S Library Construction and Sequencing
Samples were taken through one of two library construction protocols: one using Qiagen DNA Taq Polymerase (Cat. no. 201203) and another using  KAPA HotStart Taq DNA Polymerase (Kit Code KK1509). Both protocols called for PCR A, DNA clean-up, PCR B, gel electrophoresis to confirm amplification, DNA clean-up, and DNA quantification. PCR A had an annealing temperature at 52 °C for 30 seconds and elongation at 72 °C for 1 minute and 30 seconds, for 10 cycles. PCR B had an annealing temperature at 62 °C for 30 seconds and elongation at 72 °C for 1 minute and 30 seconds, for 18 cycles. Clean-up was done using Agencourt AMPure XP magnetic beads (Part number A63882), using a 1:1 bead to DNA volume ratio. The quantification at the end was done using  Quant-iT dsDNA Assay Kit and Qubit fluorometer as listed above. Libaries were normalized to 1 ng per library and pooled in batches of 80-100 for sequencing.  Sequencing was performed on an Illumina MiSeq at the UC Davis Genome Center DNA Technologies Core, using either PE250 or PE300 sequencing chemistry.

##Data Processing
Raw Illumina data was demultiplexed and checked for quality using an in house custom pipeline, *Demul\_trim\_prep_250.pl* (available at [Guthub](https://github.com/gjospin/scripts/blob/master/Demul_trim_prep_250.pl)). Default data processing parameters were determined according to recent quality filtering recommendations for Illumina data \cite{Bokulich2013}. Aquarium samples were sequenced across four Illumina MiSeq runs, using dual index barcodes to differentiate samples within each run. Samples were demuliplexed by matching nucleotide barcodes to Illumina index reads, allowing for 1 mismatch at most for each index mate. For quality control, sequence reads were trimmed when the end base reached a minimum score of Q20 (moving inward from the end of each read), and the last 50 bp was removed from PE-300 reads (since longer reads spanned more than the targeted fragment and extended into the Illumina adapter). Once the reads were trimmed and quality controlled, paired-end reads were merged using FLASH \cite{magovc2011flash} with read length parameters set as 250 or 300 depending on the Illumina sequencing chemistry; minimum overlap was set at 10 bp and maximum at 120 bp. All other parameters were left as default. Paired-end reads that did not merge successfully were discarded. After the reads were merged the files were reformatted from fastq to fasta, with fasta headers reformatted to match QIIME requirements (>SampleName_SeqNumber) and agree with sample names listed in the master metadata mapping file. Processed sequence data from the four Illumina runs was concatenated into a single file before QIIME analysis, re-numbering sequence numbering where required for samples that were re-sequenced multiple times. Raw data has been deposited into the NCBI SRA (BioProject 284506), and QIIME-ready processed sequences are available on [Figshare](http://dx.doi.org/10.6084/m9.figshare.1427397).

##Data Analysis
All downstream data processing was carried out using QIIME version 1.8.0 \cite{Caporaso2010}. Paired-end reads that successfully overlapped and merged were carried through into open-reference OTU picking using the *pick\_open\_reference\_otus.py* script. We chose an open-reference approach as the most preferable OTU picking method for the aquarium samples, since closed reference (database-dependent) approaches were likely to exclude a significant amount of microbial diversity that may have been present in such a poorly characterized marine habitat. OTU picking workflows were carried out using the default method (uclust) and parameters, with the addition of the --enable\_rev\_strand\_match flag which allowed for input reads to be assessed in both standard and reverse complemented orientations. The level of subsampling was set at 10% (-s 0.10). Taxonomy assignments were carried out using the default algorithm (uclust consensus taxonomy assigner) and the latest QIIME-formatted release of the Greengenes database collapsed at 97% sequence identity (gg\_otus-13\_8-release).

Chimera checking was run on the resulting 16S OTUs by executing the ChimeraSlayer algorithm, as implemented in QIIME script *parallel\_identify\_chimeric\_seqs.py*. Flagged chimeras were subsequently filtered out of the OTU table and removed from further downstream analysis. To clean up the dataset further, OTU tables were then further filtered by 1) removing sequences assigned to Chloroplast and Mitochondria, 2) removing OTUs with taxonomy assignments listed as "unassigned" at the root level, and 3) removing any OTUs whose representative sequences failed to align to the 16S Greengenes database using the *parallel\_align\_seqs\_pynast.py* script. Beta diversity analyses were carried out using the *beta\_diversity\_through\_plots.py*, including Bray Curtis, Jaccard, Canberra and weighted/unweighted Unifrac.

All QIIME outputs have been made publicly available on [Github](https://github.com/hollybik/aquarium_project). The accompanying iPython notebook **(URL HERE)** contains full documentation of all the command line analyses and parameters employed during the course of this study.
 
  
  